package sav.example.javaz;
import sav.z.*;

import java.io.*;
/**
 * This is example of the Base methods, which may accelerate
 * performance against the execution of Zigzag scripts.
 * It is possible a direct access to the attribute values
 * of known objects.
 */
public class DBGroupingTest {
  public static void main(String arg[]) throws IOException {
    String script =
      "$readTable() <" +
      "department; profile;        director \n" +
      "1;          'development';  101      \n" +
      "2;          'marketing';    103      \n" +
      "3;          'support':'IT'; 104      \n" +
      "4;          'billing';               \n" +
      ">;" +
      "$readTable() <" +
      "employee; name;           department; salary \n" +
      "101;      'Adams Smith';  1;          50000 \n" +
      "102;      'Clark White';  1;          30000 \n" +
      "103;      'Jones Hunter'; 2;          60000 \n" +
      "104;      'Blake Dull';   3;          65000 \n" +
      "105;      'Sylvia Smith'; 1;          25000 \n" +
      "108;      'Albert Green'; 3;          40000 \n" +
      "109;      'Clark Ringer'; 2;          50000 \n" +
      ">;"
    ;
    Session ss = new Session();
    ss.modifyBase("CompanyX");
    ss.z(script);

    /*  */
    ss.exploreBase("CompanyX");
    Base bx = ss.base();
    int depCount = bx.size("department");
    int peopleCount[] = new int[depCount + 1];
    float salarySum[] = new float[depCount + 1];
    String division[] = new String[depCount + 1];
    for (String emp = bx.first("employee"); emp != null; emp = bx.next("employee", emp)) {
      String s = bx.attrValue("employee:" + emp, "department");
      int depNumber = Integer.parseInt(s);
      if (division[depNumber] == null)
        division[depNumber] = bx.attrTerm("department:" + depNumber, "profile");
      peopleCount[depNumber]++;
      s = bx.attrValue("employee:" + emp, "salary");
      salarySum[depNumber] += Float.parseFloat(s);
    }
    System.out.println("division; people_count; salary_sum");
    for (int i = 1; i <= depCount; ++i) {
      if (division[i] == null)
        continue;
      System.out.println(division[i] + "; " +  peopleCount[i] + "; " + salarySum[i]);
    }
    bx.close();
  }
}
